.columns .column {
  width:48%;
  float:left;
  margin-right:2%;
  margin-left:1px;
}

.columns .column.last {
  float:right;
  margin-right:0;
}

.columns .column .listing {
  margin:0 !important;
  font-size:0.9em;
}

.nowrap {
  white-space:nowrap;
}

.fileexchange {
  position:relative;
}

.fileexchange .documentFirstHeading {
  padding-right:15em;
  margin-bottom:1em;
}

div.fileexchange .box {
  padding:0 1em 1em 1em;
  margin:1em 0 2em 0 !important;
  border:1px solid #ccc;
  font-size:1.2em;
}

div.fileexchange dl.form_box {
  border:none !important;
  margin:0;
  height:auto;
}

dl.form_box dt {
  display:none;
}

#add_file dt {
  display:block;
  position:absolute;
  top:0;
  right:0;
  margin:0 0 0 0;
  line-height:1.4em;
  font-size:1.2em;
  padding:0 0 0 30px;
  background-image:url(++resource++add_file_icon.gif);
  color:#627CA2;
}

#add_file dt:hover {
  color:#224B89;
}

.form_box dd {
  position:relative;
  margin:1em 0 2em 0 !important;
  clear:both;
  height:48px;
}

html > body .form_box dd {
  min-height:48px;
  height:auto;
}

.form_box .box fieldset {
  position:relative;
  padding:0;
  border:none;
}

.form_box .box fieldset legend {
  display:block;
  float:none !important;
  width:auto;
  padding:0;
  margin-bottom:1em;
  font-size:1.2em;
  font-weight:bold;
}

.form_box .box .field {
  margin-bottom:0;
}

.form_box .box label {
  clear:both;
  width:10%;
  float:left;
  margin-bottom:1em;
  .margin-bottom:0;
}

.form_box .box .formControls {
  margin:0;
  clear:both;
}

.form_box .formControls {
  position:absolute;
  right:0;
  bottom:0;
}

.form_box .box input {
  width:50%;
  float:left;
  padding:0.2em;
  margin:0;
}

.form_box .box .error input {
  border-color:#FFA500;
}

.form_box .box .error {
  padding:0;
  background-color:transparent;
  border:none;
}

.form_box .box .error div {
  clear:both;
  margin-left:10%;
  margin-top:1em;
  margin-bottom:0.5em;
  border:1px solid #FFA500;
  background-color:#FFCE7B;
  padding:0.2em;
  font-size:0.8em;
  color:#000;
  width:50.1%;
  .margin-left:9.5%;
}

.form_box .box .formControls input {
  float:none;
}

.form_box .formControls input.context {
  border:none;
  background-image:url(++resource++add_file_icon_big.gif) !important;
  padding:64px 0 0 64px !important;
  width:0 !important;
  height:0 !important;
  overflow:hidden !important;
  .height:64px !important;
  .width:64px !important;
}

#files_received h3, #files_by_user h3 {
  background-repeat:no-repeat;
  background-position:right center;
  margin-right:5px !important;
  margin-bottom:5px !important;
  margin-top:0 !important;
}

#files_received h3 {
  background-image:url("++resource++received_files_icon.gif");
}

#files_by_user h3 {
  background-image:url("++resource++user_files_icon.gif");
}