from zope.interface.interface import Interface as Z3Interface

class IFileExchangeContainer(Z3Interface):
    """FileExchangeContainer marker interface
    """

class IFileExchangeFile(Z3Interface):
    """FileExchangeFile marker interface
    """