PROJECTNAME = "FileExchange"

ADD_PERMISSIONS = {'FileExchange Container': "Raptus: Add FileExchange Container",
                   'FileExchange File'     : "Raptus: Add FileExchange File",}

MODIFY_PERMISSION = 'Raptus: Modify FileExchange File'